isSuccess property
bool
get
isSuccess
Returns true if this instance represents a successful result.
Implementation
bool get isSuccess => this is MirrorSuccess<T>;
Returns true if this instance represents a successful result.
bool get isSuccess => this is MirrorSuccess<T>;